@@ -47,13 +47,10 @@ plot.PCA =function(indata, batch, figure.dir, PCA.fig.title, legend.position = '
    if(ofile) invisible(dev.off())
 }
 
-## ----install_DeMixT-----------------------------------------------------------
-# devtools::install_github("wwylab/DeMixT")
-
 ## ----Algorithm, echo=FALSE, out.width='100%'----------------------------------
 knitr::include_graphics(path = paste0("Algorithm.png"))
 
-## ---- sim_2comp_GS, results="hide", message=FALSE-----------------------------
+## ----sim_2comp_GS, results="hide", message=FALSE------------------------------
 data("test.data.2comp")
 # res.GS = DeMixT_GS(data.Y = test.data.2comp$data.Y, 
 #                     data.N1 = test.data.2comp$data.N1,
@@ -67,7 +64,7 @@ load('Res_2comp/res.GS.RData')
 head(t(res.GS$pi))
 head(res.GS$gene.name)
 
-## ---- sim_2comp_S2, results="hide", message=FALSE-----------------------------
+## ----sim_2comp_S2, results="hide", message=FALSE------------------------------
 data("test.data.2comp")
 # res.S2 <- DeMixT_S2(data.Y = test.data.2comp$data.Y, 
 #                     data.N1 = test.data.2comp$data.N1,
@@ -144,21 +141,17 @@ ggplot(res.3comp, aes(x=True.Proportion, y=Estimated.Proportion, group = Compone
   scale_shape_manual(values=c(seq(1:3))) +
   labs(x = 'True Proportion', y = 'Estimated Proportion')  
 
-## ----read_data_PRAD,  warning=FALSE, message=FALSE----------------------------
-load('res.PRAD.RData'); 
+## ----load_data, fig.height = 4, fig.width = 6, fig.align='center', warning=FALSE----
+load(url("https://wwylab.github.io/DeMixT/etc/PRAD.RData"))
 
-## ----PRAD, fig.height = 4, fig.width = 6, fig.align='center', warning=FALSE----
-res.PRAD.df = as.data.frame(cbind(res.PRAD$res.GS.PRAD, res.PRAD$res.GS.SP.PRAD))
-res.PRAD.df$V1 <- as.numeric(as.character(res.PRAD.df$V1))
-res.PRAD.df$V2 <- as.numeric(as.character(res.PRAD.df$V2))
-names(res.PRAD.df) = c('Estimated.Proportion', 'Estimated.Proportion.SP')
-## Plot
-ggplot(res.PRAD.df, aes(x=Estimated.Proportion, y=Estimated.Proportion.SP)) +
-  geom_point() + 
-  geom_abline(intercept = 0, slope = 1, linetype = "dashed", color = "black", lwd = 0.5) +
-  xlim(0,1) + ylim(0,1)  +
-  scale_shape_manual(values=c(seq(1:3))) +
-  labs(x = 'Estimated Proportion', y = 'Estimated Proportion After Spike-in')  
+## ----view_data, fig.height = 4, fig.width = 6, fig.align='center', warning=FALSE----
+head(PRAD[,1:5])
+cat('Number of genes: ', dim(PRAD)[1], '\n')
+cat('Number of normal sample: ', length(Normal.id), '\n')
+cat('Number of tumor sample: ', length(Tumor.id), '\n')
+
+## ----correlation, echo=FALSE, out.width='100%'--------------------------------
+knitr::include_graphics(path = paste0("pairwise_correlation.png"))
 
 ## ----GTEx, echo=FALSE, out.width='65%', fig.align='center'--------------------
 knitr::include_graphics(path = paste0("GTEx_normal.png"))
